
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Scanner;

/**
 * This program shows how one can: 
 * 1) read text from a file using the File and Scanner classes. 
 * 2) write text to a file using the PrintWriter class.
 */
public class IOExample {

    public static void main(String[] args) {
        ArrayList<Double> myList = new ArrayList();

        myList = readArrayFile("src\\datafile");
        System.out.println("Data: " + toString(myList));

        // Change values in list
        for (int i = 0; i < myList.size(); i++) {
            myList.set(i, 2 * myList.get(i));
        }
        System.out.println("Updated Data: " + toString(myList));

        writeArrayFile("src\\outfile", myList);
    }

    /**
     * Read data from a file
     *
     * @param fname the name of the input file
     * @return the ArrayList containing the data read from file.
     */
    public static ArrayList readArrayFile(String fname) {
        ArrayList<Double> list = new ArrayList<Double>();
        try {
            File infile = new File(fname);
            Scanner in = new Scanner(infile);
            while (in.hasNextDouble()) {
                double value = in.nextDouble();
                list.add(value);
            }
            in.close();
        } catch (FileNotFoundException e) {
            System.out.println("Input File is not found. " + e);
            System.exit(0);
        }
        return list;
    }

    /**
     * Write values out to File
     *
     * @param fname the name of the output file
     * @param list the data to write to the file
     */
    public static void writeArrayFile(String fname, ArrayList<Double> list) {
        try {
            PrintWriter out = new PrintWriter(fname);
            for (double d : list) {
                out.println(d);
            }
            out.close();
        } catch (FileNotFoundException e) {
            System.out.println("Error writing to output. ");
            System.exit(0);
        }
    }

    /**
     * Create String representation of the items in the ArrayList
     *
     * @param list the ArrayList
     * @return the String representation
     */
    public static String toString(ArrayList<Double> list) {
        String s = "";
        for (int i = 0; i < list.size() - 1; i++) {
            s += list.get(i) + ", ";
        }
        s += list.get(list.size() - 1);
        return s;
    }
}
